# sub-index

[![NPM version](https://img.shields.io/npm/v/str-indexes-of.svg)](https://www.npmjs.com/package/str-indexes-of)
[![Bower version](https://img.shields.io/bower/v/str-indexes-of.svg)](https://github.com/shinnn/str-indexes-of/releases)
[![Build Status](https://travis-ci.org/shinnn/str-indexes-of.svg?branch=master)](https://travis-ci.org/shinnn/str-indexes-of)
[![Coverage Status](https://img.shields.io/coveralls/shinnn/str-indexes-of.svg)](https://coveralls.io/r/shinnn/str-indexes-of)
[![devDependencies Status](https://david-dm.org/shinnn/str-indexes-of/dev-status.svg)](https://david-dm.org/shinnn/str-indexes-of?type=dev)

Find an array index of the substitute value that should be chosen when a given index is deleted

```javascript
import subIndex from 'sub-index';

const array = new Array(3);

subIndex(array, 1); //=> 0
subIndex(array, 2); //=> 1
subIndex(array, 3); //=> 2

subIndex(array, 0); //=> 1
```

## Installation

### [npm](https://www.npmjs.com/)

```
npm install sub-index
```

### [bower](https://bower.io/)

```
bower install sub-index
```

## API

### subIndex(*array*, *index*)

*array*: `Array` (non-empty array)  
*index*: `Number` (index of the array)  
Return: `Number` or `null`

Essentially, it returns the predecessor number of a given `index`.

```
index:      0 1 2
value:      A B C
deleted:      ^
substitute: ^
```

```javascript
subIndex(['A', 'B', 'C'], 1); //=> 0
```

If `index` is `0`, it returns the successor number `1` because the first element has no predecessor elements;

```
index:      0 1 2
value:      A B C
deleted:    ^
substitute:   ^
```

```javascript
subIndex(['A', 'B', 'C'], 0); //=> 1
```

If the array includes only a single value, it returns `null` because no substitute can be selected;

```
index:      0
value:      A
deleted:    ^
substitute: (none)
```

```javascript
subIndex(['A'], 0); //=> null
```

## License

Copyright (c) 2016 [Shinnosuke Watanabe](https://github.com/shinnn)

Licensed under [the MIT License](./LICENSE).
